#
# spec file for package python-bibtexparser
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-bibtexparser
Version:        1.4.1
Release:        1.6
Summary:        Bibtex parser for python
License:        BSD-3-Clause OR LGPL-3.0-only
URL:            https://github.com/sciunto-org/python-bibtexparser
Source:         https://github.com/sciunto-org/python-bibtexparser/archive/v%{version}.tar.gz#/python-bibtexparser-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyparsing >= 2.0.3
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pyparsing >= 2.0.3}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python library to parse bibtex files.

%prep
%autosetup -p1 -n python-bibtexparser-%{version}
sed -i -e '/^#!\//, 1d' bibtexparser/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=C.utf8
%pytest

%files %{python_files}
%doc README.rst CHANGELOG
%license COPYING
%{python_sitelib}/bibtexparser
%{python_sitelib}/bibtexparser-%{version}.dist-info

%changelog
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Set `align_values` to an int or bool to fix min alignment in
    writing
  * Fix some docstrings
  * `customization.getnames`: respect protected names
  * No dict caching in bibdatabase. This makes
    the library slightly slower in some cases, but fixes
    previously wrong caching.
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4.0:
  * Using common strings in string interpolation is now the default.
  * Add option to adjust alignment of text of multi-line values.
  * Raise warning if parser is used multiple times, which leads to a
    merged library.
  * Allow preservation of existing order of entry fields in writer
  * Support for python 3.10
  * Removing unused dependencies
  * Allow capital AND when splitting author list
  * Fix problem in `homogenize_latex_encoding` when authors are lists
  * Long description in setup.py
- Switch to pyproject macros.
- Drop patch python-bibtexparser-remove-unittest2.patch, dependency
  dropped.
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * drop python2 support
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- Fix condition around BuildRequirement
* Mon Aug 17 2020 Matej Cepl <mcepl@suse.com>
- Remove unnecessary BR on devel.
- Don't build python2 on Tumbleweed.
* Tue Jun 30 2020 Matej Cepl <mcepl@suse.com>
- Added explanation in SPEC file
* Mon Jun  1 2020 pgajdos@suse.com
- unittest2 is not neccessary for python3
- added patches
  use unittest2 only if present, fall back to unittest
  + python-bibtexparser-remove-unittest2.patch
* Wed Apr 15 2020 Matej Cepl <mcepl@suse.com>
- Switch from using nosetest runner to pytest
* Thu May  2 2019 Todd R <toddrme2178@gmail.com>
- Initial version
